# Supplementary data

## Structures and Properties

The structures of the QM9 and Elpasolite data sets that we used are stored in extended xyz format (see https://libatoms.github.io/QUIP/io.html#extendedxyz) in two files corresponding to the optimization set and the performance evaluation set. These structure can be conveniently loaded and manipulated with python and the ASE package (https://wiki.fysik.dtu.dk/ase/index.html):
```
from ase.io import read
structures = read('qm9_5000.xyz',index=':')
```

The corresponding formation energies (in eV/atom) are stored in .npy format which can be conveniently loaded and manipulated with python and the numpy package (http://www.numpy.org/):
```
import numpy as np
property = np.load('qm9_eV_5000.dHf_peratom.npy')
```

For the elpasolite crystals, the formation energies (eV/atom) are stored in text files (.dat).

## Grid Search details

The results of the two grid searches are available in JSON format which can be conveniently read and explored with python and the pandas package (http://pandas.pydata.org/):
```
import pandas as pd
df_rs = pd.read_json('radial_scaling_gs_SI.json')
df_ch = pd.read_json('chem_corr_gs_SI.json')
```

### Radial Scaling on QM9

The columns label of the pandas DataFrame correspond to:
+ CORR : Pearson’s correlation coefficient
+ MAE : Mean Absolute Error (eV/atom)
+ R2 : Determination coefficent
+ RMSE : Root Mean Square error (eV/atom)
+ SUP : Supremum error (eV/atom)
+ centerweight : central atom weight ($u_0$)
+ cutoff_dexp : exponent of the radial scaling $m$
+ cutoff_scale : scale of the radial scaling $r_0$
+ sigma : regularization parameter of the KRR

### Chemical Correlations on QM9

+ CORR : Pearson’s correlation coefficient
+ MAE : Mean Absolute Error (eV/atom)
+ R2 : Determination coefficent
+ RMSE : Root Mean Square error (eV/atom)
+ SUP : Supremum error (eV/atom)
+ s_electro : standard deviation for the Pauling's atomic electronegativity $\sigma_{\epsilon}$
+ s_vdwr : standard deviation for the van der Waals radii $\sigma_{r}$
+ sigma : regularization parameter of the KRR
       
## Learning Curves and Other Elpasolite Crystals Files

The elpasolite crystals learning curves are supplied in text format, dj1_avgmae.dat for example. The first column refers to the number of training structures while the second refers to the average Mean Absolute Error over five test sets.

Three optimised u matrices are provided in .npy format, e.g.  u_nalch1_niter50_elpasolite_shuf1_nmax8_lmax6_rc5_aw0.3.npy. Note that "nalch" refers to the dimensionality of the element space and "niter" refers to the number of cycles of ten L-BFGS iterations.

All of the SOAP descriptors used to create the elpasolite crystals learning curves were created with the following parameters,

+ Gaussian width = 0.3 Angstrom
+ Cutoff distance = 5.0 Angstrom
+ Central atom weight = 1.0
+ nmax = 12
+ lmax = 9

For optimization of the u matrix, a descriptor with the same SOAP parameters was used, except for nmax and lmax which were changed to

+ nmax = 8
+ lmax = 6

For the learning curves and u matrix optimization, the regularisation parameter was set to 1.0e-1.5 eV/atom.